using BinaryProvider # requires BinaryProvider 0.3.0 or later

# Parse some basic command-line arguments
const verbose = "--verbose" in ARGS
const prefix = Prefix(get([a for a in ARGS if a != "--verbose"], 1, joinpath(@__DIR__, "usr")))
products = [
    LibraryProduct(prefix, ["libarpack"], :libarpack),
]

# Download binaries from hosted location
bin_prefix = "https://github.com/JuliaBinaryWrappers/Arpack_jll.jl/releases/download/Arpack-v3.5.0+2"

# Listing of files generated by BinaryBuilder:
download_info = Dict(
    Linux(:aarch64, libc=:glibc, compiler_abi=CompilerABI(:gcc4)) => ("$bin_prefix/Arpack.v3.5.0.aarch64-linux-gnu-libgfortran3.tar.gz", "3043b8066d09d3d938db3b6c4cf963341e1adbe7883feacb5ae12b31c05dc3d4"),
    Linux(:aarch64, libc=:glibc, compiler_abi=CompilerABI(:gcc7)) => ("$bin_prefix/Arpack.v3.5.0.aarch64-linux-gnu-libgfortran4.tar.gz", "83f5b08f5bf6b1a7fd72dc1438bb34bd1ac6b1082a9607cd32b6ffa9fb0fd873"),
    Linux(:aarch64, libc=:glibc, compiler_abi=CompilerABI(:gcc8)) => ("$bin_prefix/Arpack.v3.5.0.aarch64-linux-gnu-libgfortran5.tar.gz", "d64b48cee22cef29375f1041f8a646f9f9407a35ad28f8c76f2661f57aadf330"),
    Linux(:aarch64, libc=:musl, compiler_abi=CompilerABI(:gcc4)) => ("$bin_prefix/Arpack.v3.5.0.aarch64-linux-musl-libgfortran3.tar.gz", "0810bb0f1ca3d6677ba91622051c6ecc2ffa535f526f765d81dcd5c64f3f3e49"),
    Linux(:aarch64, libc=:musl, compiler_abi=CompilerABI(:gcc7)) => ("$bin_prefix/Arpack.v3.5.0.aarch64-linux-musl-libgfortran4.tar.gz", "2e82848f3ee40adc91b29cd4238cf9f1277938c8ef18e93d0db10cef7346efe0"),
    Linux(:aarch64, libc=:musl, compiler_abi=CompilerABI(:gcc8)) => ("$bin_prefix/Arpack.v3.5.0.aarch64-linux-musl-libgfortran5.tar.gz", "12d4df9b810f74474fc84ff54c0582e58a8d6e5030553e2c5cf84edff0ff7181"),
    Linux(:armv7l, libc=:glibc, call_abi=:eabihf, compiler_abi=CompilerABI(:gcc4)) => ("$bin_prefix/Arpack.v3.5.0.arm-linux-gnueabihf-libgfortran3.tar.gz", "a52971708fbc378b4f041a90ceec98cb82f00d41cc138061897447593a1b2b59"),
    Linux(:armv7l, libc=:glibc, call_abi=:eabihf, compiler_abi=CompilerABI(:gcc7)) => ("$bin_prefix/Arpack.v3.5.0.arm-linux-gnueabihf-libgfortran4.tar.gz", "e5062daaeb759fd48cb311104c92d261c178c68d7f980cbc0b151e1f40f1eef1"),
    Linux(:armv7l, libc=:glibc, call_abi=:eabihf, compiler_abi=CompilerABI(:gcc8)) => ("$bin_prefix/Arpack.v3.5.0.arm-linux-gnueabihf-libgfortran5.tar.gz", "830c3639a8e0d521363c371268113e6546bbc44acb42d14d4cf2d13af6e9bf98"),
    Linux(:armv7l, libc=:musl, call_abi=:eabihf, compiler_abi=CompilerABI(:gcc4)) => ("$bin_prefix/Arpack.v3.5.0.arm-linux-musleabihf-libgfortran3.tar.gz", "bd6c89735b7db1a9ff7d8b4098b43cc7487a2381d1109b8f1d9b4c8fb0f9040b"),
    Linux(:armv7l, libc=:musl, call_abi=:eabihf, compiler_abi=CompilerABI(:gcc7)) => ("$bin_prefix/Arpack.v3.5.0.arm-linux-musleabihf-libgfortran4.tar.gz", "0592f1b7a60fa6bf0e108b911f4c4546fd5ea03560f094d27ebd249fea9958da"),
    Linux(:armv7l, libc=:musl, call_abi=:eabihf, compiler_abi=CompilerABI(:gcc8)) => ("$bin_prefix/Arpack.v3.5.0.arm-linux-musleabihf-libgfortran5.tar.gz", "5248600a0c541e85021e2fb6b74775f0429701c8d60288adbbbb118348fb3731"),
    Linux(:i686, libc=:glibc, compiler_abi=CompilerABI(:gcc4)) => ("$bin_prefix/Arpack.v3.5.0.i686-linux-gnu-libgfortran3.tar.gz", "c29bee8279cce6b7a9582903854c2f440770924b86cb8a6073c854f005df8d6d"),
    Linux(:i686, libc=:glibc, compiler_abi=CompilerABI(:gcc7)) => ("$bin_prefix/Arpack.v3.5.0.i686-linux-gnu-libgfortran4.tar.gz", "237a2ff1fb8044e4ad0b956e028d4c64359e4397614b851b045960c74391c190"),
    Linux(:i686, libc=:glibc, compiler_abi=CompilerABI(:gcc8)) => ("$bin_prefix/Arpack.v3.5.0.i686-linux-gnu-libgfortran5.tar.gz", "38f099c40a14da6de823d14acc199e16c80f929fc1f0115365204e22f9eaf1eb"),
    Linux(:i686, libc=:musl, compiler_abi=CompilerABI(:gcc4)) => ("$bin_prefix/Arpack.v3.5.0.i686-linux-musl-libgfortran3.tar.gz", "6afe3373a88b00cba91629627356d1c7167b06be7a573b8906e0a657e86b0391"),
    Linux(:i686, libc=:musl, compiler_abi=CompilerABI(:gcc7)) => ("$bin_prefix/Arpack.v3.5.0.i686-linux-musl-libgfortran4.tar.gz", "51b26aaf5fce2c600845060ac50abfa74294a31d4e7b6183238457359f4b3c84"),
    Linux(:i686, libc=:musl, compiler_abi=CompilerABI(:gcc8)) => ("$bin_prefix/Arpack.v3.5.0.i686-linux-musl-libgfortran5.tar.gz", "18bff92384c0175e16b385e4cf6e557657fa1d008c09cccbbb16829b4f85328e"),
    Windows(:i686, compiler_abi=CompilerABI(:gcc4)) => ("$bin_prefix/Arpack.v3.5.0.i686-w64-mingw32-libgfortran3.tar.gz", "72c6811ec0c0ab5962434b4893b611094595efa984dc05fc07011c350c292905"),
    Windows(:i686, compiler_abi=CompilerABI(:gcc7)) => ("$bin_prefix/Arpack.v3.5.0.i686-w64-mingw32-libgfortran4.tar.gz", "15b30b823bc10fe1ddeeaa236cac274065c5b06c52cfa307116b1af117637bc9"),
    Windows(:i686, compiler_abi=CompilerABI(:gcc8)) => ("$bin_prefix/Arpack.v3.5.0.i686-w64-mingw32-libgfortran5.tar.gz", "68eaa7d51924d921e8fc7d236226bc8f79644ac440023755a878d967c3f754c4"),
    Linux(:powerpc64le, libc=:glibc, compiler_abi=CompilerABI(:gcc4)) => ("$bin_prefix/Arpack.v3.5.0.powerpc64le-linux-gnu-libgfortran3.tar.gz", "be93a559a8794b0560658eeba1e867b699b516bc3442011c2edd647760bf6f15"),
    Linux(:powerpc64le, libc=:glibc, compiler_abi=CompilerABI(:gcc7)) => ("$bin_prefix/Arpack.v3.5.0.powerpc64le-linux-gnu-libgfortran4.tar.gz", "30e90a37b8841493b9797e23853133c8cd9d1cbeff5bc6764b73483b5a43e994"),
    Linux(:powerpc64le, libc=:glibc, compiler_abi=CompilerABI(:gcc8)) => ("$bin_prefix/Arpack.v3.5.0.powerpc64le-linux-gnu-libgfortran5.tar.gz", "d3bb3bddf4b65000cc3c43ee980da3d3833b9f355f762711d707fdae5af0ef49"),
    MacOS(:x86_64, compiler_abi=CompilerABI(:gcc4)) => ("$bin_prefix/Arpack.v3.5.0.x86_64-apple-darwin14-libgfortran3.tar.gz", "1d78c69a2c0317dd79a8b5a23475f1d835ee7f491dd37adae0a5a89cd341d3b8"),
    MacOS(:x86_64, compiler_abi=CompilerABI(:gcc7)) => ("$bin_prefix/Arpack.v3.5.0.x86_64-apple-darwin14-libgfortran4.tar.gz", "1fce88c32fa2b2f576b6d78f4ca42e3511fbf36f46ef3dd5340c7921b247f171"),
    MacOS(:x86_64, compiler_abi=CompilerABI(:gcc8)) => ("$bin_prefix/Arpack.v3.5.0.x86_64-apple-darwin14-libgfortran5.tar.gz", "34de116f3e4c9cfd0168d15437a09e5c5b744cecae525f02848420f7ef09e09f"),
    Linux(:x86_64, libc=:glibc, compiler_abi=CompilerABI(:gcc4)) => ("$bin_prefix/Arpack.v3.5.0.x86_64-linux-gnu-libgfortran3.tar.gz", "3622daa560d42d8995cb77dc53030e070cc9aa7b0748e6dcfefae8b2ea9fc641"),
    Linux(:x86_64, libc=:glibc, compiler_abi=CompilerABI(:gcc7)) => ("$bin_prefix/Arpack.v3.5.0.x86_64-linux-gnu-libgfortran4.tar.gz", "887fcc8deb13510589054ab4b72b376f43ab27ffe8e260739fecfba2f2852b82"),
    Linux(:x86_64, libc=:glibc, compiler_abi=CompilerABI(:gcc8)) => ("$bin_prefix/Arpack.v3.5.0.x86_64-linux-gnu-libgfortran5.tar.gz", "c51d115bfe318e5a8e0bff3fa26173ee186ff4604e5387cd6d412519c84ca469"),
    Linux(:x86_64, libc=:musl, compiler_abi=CompilerABI(:gcc4)) => ("$bin_prefix/Arpack.v3.5.0.x86_64-linux-musl-libgfortran3.tar.gz", "0d67d4c780b212962af288266f871d494890285d6a7fd1b8d55bc6c3e948e844"),
    Linux(:x86_64, libc=:musl, compiler_abi=CompilerABI(:gcc7)) => ("$bin_prefix/Arpack.v3.5.0.x86_64-linux-musl-libgfortran4.tar.gz", "6fd4d11409566cdfa1dc4f4a3c57fc355c07d41953ffad8a44d9812e1adc5edf"),
    Linux(:x86_64, libc=:musl, compiler_abi=CompilerABI(:gcc8)) => ("$bin_prefix/Arpack.v3.5.0.x86_64-linux-musl-libgfortran5.tar.gz", "ee539289e1ad1b79d2ea87a4c9059c4d65459fe1aefd2a163f8f63ef342c7ab7"),
    FreeBSD(:x86_64, compiler_abi=CompilerABI(:gcc4)) => ("$bin_prefix/Arpack.v3.5.0.x86_64-unknown-freebsd11.1-libgfortran3.tar.gz", "e66e0881b28bf6a46152222bb3e6bc9c432c38437fd5e24966daafc1b48df0d5"),
    FreeBSD(:x86_64, compiler_abi=CompilerABI(:gcc7)) => ("$bin_prefix/Arpack.v3.5.0.x86_64-unknown-freebsd11.1-libgfortran4.tar.gz", "4552d5fd4ce24f4f66b6a4d4812c52827695bc3e852cff2e16ba3943d8c1d820"),
    FreeBSD(:x86_64, compiler_abi=CompilerABI(:gcc8)) => ("$bin_prefix/Arpack.v3.5.0.x86_64-unknown-freebsd11.1-libgfortran5.tar.gz", "763a5c445bedf476e67561891e32249fe7914520b889a5e74a6d36c61d46cc35"),
    Windows(:x86_64, compiler_abi=CompilerABI(:gcc4)) => ("$bin_prefix/Arpack.v3.5.0.x86_64-w64-mingw32-libgfortran3.tar.gz", "eebc96753710e17678128d4ce1f7f5ec59de3cc3afd063e30f8ef6807d860310"),
    Windows(:x86_64, compiler_abi=CompilerABI(:gcc7)) => ("$bin_prefix/Arpack.v3.5.0.x86_64-w64-mingw32-libgfortran4.tar.gz", "81d5ac674df9beff08aabdf899c731daad776e3a31af5883c3d5140eeaa1d5c2"),
    Windows(:x86_64, compiler_abi=CompilerABI(:gcc8)) => ("$bin_prefix/Arpack.v3.5.0.x86_64-w64-mingw32-libgfortran5.tar.gz", "8f8d35cc3fbf1493499231e80d49728d4a68d287e40793ad780df4aef52b2779"),
)

# Install unsatisfied or updated dependencies:
unsatisfied = any(!satisfied(p; verbose=verbose) for p in products)
dl_info = choose_download(download_info, platform_key_abi())
if dl_info === nothing && unsatisfied
    # If we don't have a compatible .tar.gz to download, complain.
    # Alternatively, you could attempt to install from a separate provider,
    # build from source or something even more ambitious here.
    error("Your platform (\"$(Sys.MACHINE)\", parsed as \"$(triplet(platform_key_abi()))\") is not supported by this package!")
end

# If we have a download, and we are unsatisfied (or the version we're
# trying to install is not itself installed) then load it up!
if unsatisfied || !isinstalled(dl_info...; prefix=prefix)
    # Download and install binaries
    install(dl_info...; prefix=prefix, force=true, verbose=verbose)
end

# Write out a deps.jl file that will contain mappings for our products
write_deps_file(joinpath(@__DIR__, "deps.jl"), products, verbose=verbose)
